==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/QCustom3DVolume_shell.h <==
#ifndef QCUSTOM3DVOLUME_SHELL_H
#define QCUSTOM3DVOLUME_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qcustom3dvolume.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class QCustom3DVolume_shell : public QtDataVisualization::QCustom3DVolume, public QtJambiShellInterface
{
public:
    QCustom3DVolume_shell(QObject* parent0 = nullptr);
    QCustom3DVolume_shell(const QVector3D& position0, const QVector3D& scaling1, const QQuaternion& rotation2, int textureWidth3, int textureHeight4, int textureDepth5, QVector<uchar>* textureData6, QImage::Format textureFormat7, const QVector<unsigned int>& colorTable8, QObject* parent9 = nullptr);
    ~QCustom3DVolume_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustom3DVolume_access : public QtDataVisualization::QCustom3DVolume
{
};

#endif // QCUSTOM3DVOLUME_SHELL_H

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiDataVisualization/QCustom3DVolume_shell.h <==
#ifndef QCUSTOM3DVOLUME_SHELL_H
#define QCUSTOM3DVOLUME_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDataVisualization/qcustom3dvolume.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qcolor.h>
#include <QtGui/qimage.h>
#include <QtGui/qquaternion.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class QCustom3DVolume_shell : public QCustom3DVolume, public QtJambiShellInterface
{
public:
    QCustom3DVolume_shell(QObject* parent0 = nullptr);
    QCustom3DVolume_shell(const QVector3D& position0, const QVector3D& scaling1, const QQuaternion& rotation2, int textureWidth3, int textureHeight4, int textureDepth5, QList<uchar>* textureData6, QImage::Format textureFormat7, const QList<unsigned int>& colorTable8, QObject* parent9 = nullptr);
    ~QCustom3DVolume_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QCustom3DVolume_access : public QCustom3DVolume
{
};

#endif // QCUSTOM3DVOLUME_SHELL_H
